@@ -10,7 +10,7 @@ use Mojo::Base 'Mojolicious::Plugin';
 use Mojolicious::Plugin::DigestAuth::DB;
 use Mojolicious::Plugin::DigestAuth::RequestHandler;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 sub register
 {
@@ -18,8 +18,9 @@ sub register
 
     my %defaults = %$user_defaults;
     $defaults{realm}   ||= 'WWW';
-    $defaults{secret}  ||= $app->can('secret') ? $app->secret : ($app->secrets||[])[0]; # >= 4.91 has no secret()
     $defaults{expires} ||= 300;
+    $defaults{secret}  ||= $app->can('secret') ? $app->secret : $app->secrets; # >= 4.91 has no secret()
+    $defaults{secret}  = $defaults{secret}->[0] if ref($defaults{secret}) eq 'ARRAY';
 
     $app->helper(digest_auth => sub {
         my $c = shift;
@@ -64,6 +65,8 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Mojolicious::Plugin::DigestAuth - HTTP Digest Authentication for Mojolicious
@@ -273,6 +276,15 @@ Quality of protection. Defaults to C<'auth'>.  C<auth-int> is not supported.
 
 Authentication realm. Defaults to C<'WWW'>.
 
+=item * C<< secret => 'a salt value' >>
+
+Used to create the nonce. Defaults to L<your application's secret|Mojolicious/secrets>, which means
+you must set your application's secret before loading this plugin. If you're using an array the B<first value> 
+in the array will be used.
+
+B<IMPORTANT>: Changing this value will cause an HTTP 400 response to be returned to any clients with cached authentication
+credentials.
+
 =item * C<< support_broken_browsers => 1 | 0 >>
 
 When processing requests from certain browsers skip steps that would otherwise result in a HTTP 400 response. Defaults to C<1>.
